# Compute paths

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KokkosConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib64/cmake" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

GET_FILENAME_COMPONENT(Kokkos_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)
SET(Kokkos_INCLUDE_DIRS "")

INCLUDE("${Kokkos_CMAKE_DIR}/KokkosTargets.cmake")

# These are IMPORTED targets created by KokkosTargets.cmake
SET(Kokkos_LIBRARY_DIRS    )
SET(Kokkos_SEPARATE_LIBS   OFF)
SET(Kokkos_LIBRARIES       Kokkos::kokkos)

SET(Kokkos_DEVICES                      SERIAL;OPENMP)
SET(Kokkos_OPTIONS                      TESTS;PROFILING)
SET(Kokkos_ARCH                         )

# These are needed by KokkosKernels
FOREACH(DEV ${Kokkos_DEVICES})
SET(Kokkos_ENABLE_${DEV} ON)
ENDFOREACH()

include(FindPackageHandleStandardArgs)

#   This function makes sure that Kokkos was built with the requested backends
#   and target architectures and generates a fatal error if it was not.
#
#   kokkos_check(
#     [DEVICES <devices>...] # Set of backends (e.g. "OpenMP" and/or "Cuda")
#     [ARCH <archs>...]      # Target architectures (e.g. "Power9" and/or "Volta70")
#     [OPTIONS <options>...] # Optional settings (e.g. "PROFILING")
#     [TPLS <tpls>...]       # Third party libraries
#   )
function(kokkos_check)
  set(ALLOWED_ARGS DEVICES ARCH OPTIONS TPLS)
  cmake_parse_arguments(KOKKOS_CHECK "" "" "${ALLOWED_ARGS}" ${ARGN})
  # Get the list of keywords that were actually passed to the function.
  set(REQUESTED_ARGS)
  foreach(arg ${ALLOWED_ARGS})
    if(KOKKOS_CHECK_${arg})
      list(APPEND REQUESTED_ARGS ${arg})
    endif()
  endforeach()
  set(KOKKOS_CHECK_SUCCESS TRUE)
  foreach(arg ${REQUESTED_ARGS})
    # Define variables named after the required arguments that are provided by
    # the Kokkos install.
    foreach(requested ${KOKKOS_CHECK_${arg}})
      foreach(provided ${Kokkos_${arg}})
        STRING(TOUPPER ${requested} REQUESTED_UC)
        STRING(TOUPPER ${provided}  PROVIDED_UC)
        if(PROVIDED_UC STREQUAL REQUESTED_UC)
          string(REPLACE ";" " " ${requested} "${KOKKOS_CHECK_${arg}}")
        endif()
      endforeach()
    endforeach()
    # Somewhat divert the CMake function below from its original purpose and
    # use it to check that there are variables defined for all required
    # arguments. Success or failure messages will be displayed but we are
    # responsible for signaling failure and skip the build system generation.
    find_package_handle_standard_args("Kokkos_${arg}" DEFAULT_MSG
            ${KOKKOS_CHECK_${arg}})
    if(NOT Kokkos_${arg}_FOUND)
      set(KOKKOS_CHECK_SUCCESS FALSE)
    endif()
  endforeach()
  if(NOT KOKKOS_CHECK_SUCCESS)
    message(FATAL_ERROR "Kokkos does NOT provide all backends and/or architectures requested")
  endif()
endfunction()

#Find dependencies
INCLUDE(CMakeFindDependencyMacro)
SET(FOUND_HPX_DIR )
SET(FOUND_HPX_ROOT )
#figure out if we found HPX using root or dir
#set the search path accordingly, unless it got overriden
IF (NOT DEFINED HPX_ROOT AND NOT DEFINED HPX_DIR)
  IF (FOUND_HPX_DIR)
    SET(HPX_DIR ${FOUND_HPX_DIR})
  ELSEIF(FOUND_HPX_ROOT)
    SET(HPX_ROOT ${FOUND_HPX_ROOT})
  ENDIF()
ENDIF()

SET(KOKKOS_USE_CXX_EXTENSIONS ON)
IF (NOT DEFINED CMAKE_CXX_EXTENSIONS OR CMAKE_CXX_EXTENSIONS)
  IF (NOT KOKKOS_USE_CXX_EXTENSIONS)
    MESSAGE(WARNING "The installed Kokkos configuration does not support CXX extensions. Forcing -DCMAKE_CXX_EXTENSIONS=Off")
    SET(CMAKE_CXX_EXTENSIONS OFF CACHE BOOL "" FORCE)
  ENDIF()
ENDIF()

SET(KOKKOS_ENABLE_HPX OFF)
IF (KOKKOS_ENABLE_HPX)
  FIND_DEPENDENCY(HPX)
ENDIF()

SET(HWLOC_LIBRARIES /usr/lib64/libhwloc.so)
SET(KOKKOS_ENABLE_HWLOC ON)
IF(KOKKOS_ENABLE_HWLOC)
  ADD_LIBRARY(Kokkos::hwloc UNKNOWN IMPORTED)
  SET_TARGET_PROPERTIES(Kokkos::hwloc PROPERTIES
    IMPORTED_LOCATION "${HWLOC_LIBRARIES}"
  )
ENDIF()

SET(MEMKIND_LIBRARIES )
SET(MEMKIND_INCLUDE_DIR )
SET(KOKKOS_ENABLE_MEMKIND Off)
IF(KOKKOS_ENABLE_MEMKIND)
  ADD_LIBRARY(Kokkos::memkind UNKNOWN IMPORTED)
  SET_TARGET_PROPERTIES(Kokkos::memkind PROPERTIES
    INTERFACE_INCLUDE_DIRECTORIES "${MEMKIND_INCLUDE_DIR}"
    IMPORTED_LOCATION "${MEMKIND_LIBRARIES}"
  )
ENDIF()

SET(LIBDL_LIBRARIES   /usr/lib64/libdl.so)
SET(LIBDL_INCLUDE_DIR )
#no if, always need -ldl
ADD_LIBRARY(Kokkos::libdl UNKNOWN IMPORTED)
SET_TARGET_PROPERTIES(Kokkos::libdl PROPERTIES
  INTERFACE_INCLUDE_DIRECTORIES "${LIBDL_INCLUDE_DIR}"
  IMPORTED_LOCATION "${LIBDL_LIBRARIES}"
)

SET(LIBRT_LIBRARIES )
SET(KOKKOS_ENABLE_LIBRT )
IF(KOKKOS_ENABLE_LIBRT)
  ADD_LIBRARY(Kokkos::librt UNKNOWN IMPORTED)
  SET_TARGET_PROPERTIES(Kokkos::librt PROPERTIES
    IMPORTED_LOCATION "${LIBRT_LIBRARIES}"
  )
ENDIF()
